<!--
Welcome to the Jaeger project! 👋🎉

- Please search for existing issues to avoid creating duplicate bugs/feature requests.
- Please be respectful and considerate of others when commenting on issues.
- Please provide as much information as possible so we all understand the issue.
- If you only have a question, you may get a faster response by asking in
    - our chat room https://gitter.im/jaegertracing/Lobby, or
    - the forum https://groups.google.com/d/forum/jaeger-tracing
    (but please don't double post)
-->

## Requirement - what kind of business use case are you trying to solve?

<!-- required section -->

## Problem - what in Jaeger blocks you from solving the requirement?

<!-- required section -->
<!-- If possible, describe the impact of the problem. -->

## Proposal - what do you suggest to solve the problem or improve the existing situation?

<!-- It's ok if you don't have one. -->

## Any open questions to address

<!-- Questions that should be answered before proceeding with implementation. -->
